@@ -40,6 +40,7 @@ class PlayStoreScraper:
 		url += "&gl=" + country
 
 		amount = int(num) * int(page)
+		apps = []
 
 		try:
 			result = requests.get(url).text
@@ -50,7 +51,34 @@ class PlayStoreScraper:
 		except IndexError:
 			return []
 
-		return [app[12][0] for app in data[0][1][0][0][0]][:amount]
+		apps += [app[12][0] for app in data[0][1][0][0][0]][:amount]
+
+		# part two
+		# not all apps are loaded on the page initially, so we need to make
+		# subsequent requests via the internal API to request the additional
+		# apps. This request payload was borrowed from google-play-scraper.
+		body = '[[["qnKhOb","[[null,[[10,[10,50]],true,null,[96,27,4,8,57,30,110,79,11,16,49,1,3,9,12,104,55,56,51,10,34,77]],null,\\"%token%\\"]]",null,"generic"]]]'
+		token = data[0][1][0][0][7][1]
+
+		url = self.PLAYSTORE_URL + "/_/PlayStoreUi/data/batchexecute?rpcids=qnKhOb&bl=boq_playuiserver_20190424.04_p0"
+		url += "&hl=" + lang
+		url += "&gl=" + country
+		url += "&authuser=0&soc-app=121&soc-platform=1&soc-device=1"
+		url += quote_plus(term)
+
+		while token:
+			next_request_payload = body.replace("%token%", token)
+			apps_page = requests.post(url, data={"f.req": next_request_payload}, headers={"Content-Type": "application/x-www-form-urlencoded;charset=UTF-8"})
+			apps_page = apps_page.text[4:].strip()
+			apps_page = json.loads(apps_page)
+			apps_page = json.loads(apps_page[0][2])
+
+			apps += [app[12][0] for app in apps_page[0][0][0]]
+
+			# no token means no next page
+			token = apps_page[0][0][7][1] if apps_page[0][0][7] else None
+
+		return apps
 
 	def get_app_ids_for_collection(self, collection="", category="", age="", num=50, lang="nl", country="nl"):
 		"""
@@ -231,7 +259,6 @@ class PlayStoreScraper:
 
 		:return dict:  App details, as returned by the Play Store.
 		"""
-		print(app_id)
 		url = self.PLAYSTORE_URL + "/store/apps/details?id="
 		url += quote_plus(app_id)
 
